//
//  ObservableVPNState.swift
//  Passepartout
//
//  Created by Davide De Rosa on 3/27/22.
//  Copyright (c) 2022 Davide De Rosa. All rights reserved.
//
//  https://github.com/passepartoutvpn
//
//  This file is part of Passepartout.
//
//  Passepartout is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  Passepartout is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with Passepartout.  If not, see <http://www.gnu.org/licenses/>.
//

import Foundation
import TunnelKitCore
import TunnelKitManager
import PassepartoutCore
import PassepartoutUtils

public class ObservableVPNState: WrappedVPNState, ObservableObject {
    @Published public internal(set) var isEnabled = false {
        didSet {
            pp_log.debug("VPN enabled -> \(isEnabled)")
        }
    }

    @Published public internal(set) var vpnStatus: VPNStatus = .disconnected {
        didSet {
            pp_log.debug("VPN status: \(vpnStatus)")
        }
    }

    @Published public internal(set) var lastError: Error? {
        didSet {
            guard let lastError = lastError else {
                return
            }
            pp_log.debug("Last error: \(lastError)")
        }
    }
    
    @Published public internal(set) var dataCount: DataCount? {
        didSet {
            guard let dataCount = dataCount else {
                return
            }
            pp_log.debug("Data count: \(dataCount)")
        }
    }

    public init() {
    }
}
